@@ -1,7 +1,7 @@
 <?php
 /*
     Configuration file.
-    Copyright 2003 Daniel K. Imori
+    Copyright 2003, 2004 Daniel K. Imori
 
     This file is part of vkeyboard plugin.
 
@@ -20,17 +20,23 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-# Display the message "Are you using a public computer? Enter your password
-# with the <link>" to user? [yes|no]
+// Display the message "Are you using a public computer? Enter your password
+// with the <link>" to user? [yes|no]
 
 $display_msg = 'yes';
 
-# Message and/or link text font size: [normal|small]
+// Message and/or link text font size: [normal|small]
 
 $msg_font_size = 'normal';
 
-# Link type: [text|button]
+// Link type: [text|button]
 
 $link_type = 'text';
 
+// Keyboard layout
+// Options: us_english
+//          portuguese_abnt2
+
+$kbd_layout = 'us_english';
+
 ?>
